##  Linking an Application Fact Sheet During Fact Sheet Creation
You can link an application to a catalog item from the fact sheet creation overlay. Follow these steps:
  1. Enter the name of the application in the fact sheet creation overlay. As you type the name, recommendations from the reference catalog appear below the input field.
  2. Choose the appropriate catalog item, then click Create & Link.


![Linking Application Fact Sheet During Fact Sheet Creation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757e6c17a441014bda3e121c6349dc7_LowRes.gif)
Linking Application Fact Sheet During Fact Sheet Creation
